const state = {
    loadingUsers: false,
    users: [],
    selectedUser: null,
    userSelectorIsVisible: false
}

const getters = {
    loadingUsers(state) {
        return state.loadingUsers
    },
    users(state) {
        return state.users
    },
    selectedUser(state) {
        return state.selectedUser
    },
    userSelectorIsVisible(state) {
        return state.userSelectorIsVisible
    },
    companyName(state) {
        const currentUser = state.users.find(u => u.currentUser)
        return currentUser && currentUser.company.name
    },
    isManager(state) {
        const currentUser = state.users.find(u => u.isManager)
        return currentUser && currentUser.company.name
    }
}

const mutations = {
    setLoadingUsers(state, loading) {
        state.loading = !!loading
    },
    setUsers(state, users) {
        state.users = users
        state.selectedUser = users.find(u => u.currentUser)
    },
    setSelectedUser(state, userId) {
        if (!userId) {
            state.selectedUser = null
        }

        state.selectedUser = state.users.find(u => u.id === userId)
    },
    setVisibleUserSelector(state, visible) {
        state.userSelectorIsVisible = !!visible
    }
}

const actions = {
    initUsers({ commit }, users) {
        commit('setUsers', users)
        commit('setLoadingUsers')
    },
    selectUser({ commit }, userId) {
        commit('setSelectedUser', userId)
    },
    resetUsers({ commit }) {
        commit('setUsers', [])
        commit('setSelectedUser')
        commit('setLoadingUsers')
    },
    showUserSelector({ commit }, show) {
        commit('setVisibleUserSelector', show)
    },
    resetUser({ commit }) {
        // Ignore this
    }
}

export default {
    state,
    getters,
    actions,
    mutations
}