const state = {
    loadingWarehouses: false,
    warehouses: [],
    selectedWarehouse: null
}

const getters = {
    loadingWarehouses(state) {
        return state.loadingWarehouses
    },
    warehouses(state) {
        return state.warehouses
    },
    selectedWarehouse(state) {
        return state.selectedWarehouse
    },
    showWarehouseSelector(state) {
        return state.warehouses.length > 1
    }
}

const mutations = {
    setLoadingWarehouses(state, loading) {
        state.loadingWarehouses = !!loading
    },
    setWarehouses(state, warehouses) {
        state.warehouses = warehouses
    },
    setSelectedWarehouse(state, warehouseId) {
        if (!warehouseId) {
            state.selectedWarehouse = null
        }

        state.selectedWarehouse = state.warehouses.find(w => w.id == warehouseId)
    },
    setSelectedWarehouseAuto(state) {
        state.selectedWarehouse = null

        if (state.warehouses.length == 0) {
            return
        }

        state.selectedWarehouse = state.warehouses[0]
    }
}

const actions = {
    initWarehouses({ commit }, warehouses) {
        commit('setWarehouses', warehouses)
        commit('setSelectedWarehouseAuto')
        commit('setLoadingWarehouses')
    },
    selectWarehouse({ commit }, warehouseId) {
        commit('setSelectedWarehouse', warehouseId)
    },
    autoSelectWarehouse({ commit }) {
        commit('setSelectedWarehouseAuto')
    },
    resetWarehouse({ commit }) {
        commit('setLoadingWarehouses')
        commit('setWarehouses', [])
    }
}

export default {
    state,
    getters,
    actions,
    mutations
}